## Intercept at first time point

##Nonlinear growth model NAEP Boys Math

# Install "lavaan" normally, install "blavaan" from source  -------

# install.packages("mice")
# install.packages("bayesplot")
# install.packages("lattice")
# install.packages("ggplot2")
# install.packages("car")
# install.packages("rstan")
# install.packages("rstantools")
# install.packages("lavaan")
# install.packages("blavaan")
# install.packages("runjags")
# install.packages("BMA")
# install.packages("psych")
# install.packages("DescTools")
# install.packages("LaplacesDemon")
# install.packages("BMS")
# install.packages("FNN")
# install.packages("forecast")
# install.packages("xtable")


library(mice)
library(lattice)
library(bayesplot)
library(ggplot2)
library(car)
library(lavaan)
library(blavaan)
library(BMA)
library(psych)
library(DescTools)
library(FNN)
library(forecast)
library(LaplacesDemon)
library(BMS)
library(xtable)
library(rstan)
library(rstantools)


# Data input and manipulation

# Read Final_Gender.csv   -------------
NAEPGenderScores <- read.csv("Final_Gender.csv", header=T) 
#  Remove Tennessee due to lack of data
NAEPGenderScores <- NAEPGenderScores[-c(43),]
NAEPBoysMath <- subset(NAEPGenderScores,select=c(Jurisdiction,MathBoy03,MathBoy05,MathBoy07,MathBoy09,
                                         MathBoy11,MathBoy13,MathBoy15,MathBoy17,
                                         ReadingBoy03,ReadingBoy17))

# Read Final_NAEP.csv
NAEPdataDemos  <- read.csv("Final_NAEP.csv", header=T)
#  Remove Tennessee due to lack of data
NAEPdataDemos <- NAEPdataDemos[-c(43),]


# Read CCD_imputed.csv
CCDdata <- read.csv("CCD_imputed.csv", header=T)
#  Remove Tennessee due to lack of data
CCDdata <- CCDdata[-c(43),]


NAEPBoysdata <- cbind(NAEPBoysMath, NAEPdataDemos, CCDdata)


#################################################################
# Run Gen Diff NonLinear growth curve model:  THIS ONE SEEMS BEST ------
#################################################################

BayesNonLinGCM <- '
# intercept and slope with fixed coefficients
int =~ 1*MathBoy03+1*MathBoy05+1*MathBoy07+1*MathBoy09+1*MathBoy11+1*MathBoy13+1*MathBoy15+1*MathBoy17
slp =~ 0*MathBoy03+2*MathBoy05+4*MathBoy07+MathBoy09+MathBoy11+MathBoy13+MathBoy15+MathBoy17
int ~ prior("dnorm(260,.1)")*1
'
attach(NAEPBoysdata)
#  Fit quadratic growth curve model and obtain predicted values ------
fitMathBoys <- bgrowth(BayesNonLinGCM, data=NAEPBoysdata,save.lvs=TRUE,n.chains=2,
                      target="jags",adapt=1000,burnin=5000, sample=100000,test="none",
                      bcontrol=list(method="rjparallel"))
testMathBoysSummary <- summary(fitMathBoys)

# Obtain predicted growth parameters and combine ------
lvmeansMathBoys <- blavInspect(fitMathBoys, "lvmeans")
newMathBoys <- cbind(NAEPBoysdata,lvmeansMathBoys)
which(names(newMathBoys)%in%c("TOTEXP03"))
names(newMathBoys)[298:299]=c("int","slp")
time1 <- as.matrix(c(0, 2, 4, 6.46, 7.74, 8.17, 5.57, 6.01),nrow=1,ncol=8)   # Spline 


BaselineMathBoys <- newMathBoys[,298]  + newMathBoys[,299] %*% t(time1)
newMathBoys2 <- cbind(newMathBoys,BaselineMathBoys)
which(names(newMathBoys2)%in%c("slp"))
names(newMathBoys2)[300:307] =
  c("PredMathBoy03","PredMathBoy05","PredMathBoy07","PredMathBoy09",
    "PredMathBoy11","PredMathBoy13","PredMathBoy15","PredMathBoy17")


# Create difference scores for demographics
attach(newMathBoys2)
BoysEnrollDiff = GENDER_MALE_17_g08m - GENDER_MALE_03_g08m
OtherEnrollDiff17 = 100 - GENDER_MALE_17_g08m
OtherEnrollDiff03 = 100 - GENDER_MALE_03_g08m 
OtherEnrollDiff = OtherEnrollDiff17- OtherEnrollDiff03
PTRatioDiff = PT_ratio17 - PT_ratio03
FTEdiff2 = (FTE17 - FTE03)/10000
TOTREVdiff = (TOTREV15 - TOTREV03)/10000
TOTEXPdiff <- (TOTEXP15 - TOTEXP03)/10000


ReadBoyDiff = ReadingBoy17 - ReadingBoy03

AAdiff = SDRACEM_AM_IND_17_g08m - SDRACEM_AM_IND_03_g08m
ASdiff = SDRACEM_ASIAN_PI_17_g08m - SDRACEM_ASIAN_PI_03_g08m
HIdiff = SDRACEM_HISPAN_17_g08m - SDRACEM_HISPAN_03_g08m
BLdiff = SDRACEM_BLACK_17_g08m - SDRACEM_BLACK_03_g08m
WHdiff = SDRACEM_WHITE_17_g08m - SDRACEM_WHITE_03_g08m

NSLPLunchDiff = SLUNCH1_ELIGIBLE_17_g08m - SLUNCH1_ELIGIBLE_03_g08m

NAEPBoysdata2 <- cbind(newMathBoys2,ReadBoyDiff,BoysEnrollDiff, OtherEnrollDiff,PTRatioDiff,
                         FTEdiff2,
                         NSLPLunchDiff ,
                         TOTREVdiff)


## BMA prediction of slope  ------

which(names(NAEPBoysdata2)%in%c("slp","ReadBoyDiff","BoysEnrollDiff",
                                "PTRatioDiff",
                         "FTEdiff2",
                         "NSLPLunchDiff" ,
                         "TOTREVdiff"
                              ))

BMSdataBoys <- NAEPBoysdata2[,c(299, 308, 309, 311, 312, 313, 314)]


###  Conduct BMA and assess sensitivity to differnt parameter and model prior settings ###

###### =============================================== ######
###### ================ g = uip = 1/N ================ ######
###### =============================================== ######

# LPS for static forecast - slope  g=uip, mprior=uniform
###### 1) uniform
BMSs1Boys <- bms(BMSdataBoys, g="uip",mprior="uniform")
options(scipen=999)
pdensStatic_s1 <- pred.density(BMSs1Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s1$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s1, realized.y=BMSdataBoys[,1])

# plotModelsize(BMSs1Boys)

###### 2) fixed for binomial
BMSs2aBoys <- bms(BMSdataBoys, g="uip", mprior="fixed")
options(scipen=999)
pdensStatic_s2a <- pred.density(BMSs2aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s2a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s2a, realized.y=BMSdataBoys[,1])


BMSs2bBoys <- bms(BMSdataBoys, g="uip", mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s2b <- pred.density(BMSs2bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s2b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s2b, realized.y=BMSdataBoys[,1])


BMSs2cBoys <- bms(BMSdataBoys, g="uip", mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s2c <- pred.density(BMSs2cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s2c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s2c, realized.y=BMSdataBoys[,1])



###### 3) random for beta-binomial
BMSs3Boys <- bms(BMSdataBoys, g="uip",mprior="random")
options(scipen=999)
pdensStatic_s3 <- pred.density(BMSs3Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s3$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s3, realized.y=BMSdataBoys[,1])





###### ======================================= ######
###### ============ g = RIC = K^2 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs9Boys <- bms(BMSdataBoys, g="RIC",mprior="uniform")
options(scipen=999)
pdensStatic_s9 <- pred.density(BMSs9Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s9$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s9, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs10aBoys <- bms(BMSdataBoys, g="RIC",mprior="fixed")
options(scipen=999)
pdensStatic_s10a <- pred.density(BMSs10aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s10a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s10a, realized.y=BMSdataBoys[,1])

BMSs10bBoys <- bms(BMSdataBoys, g="RIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s10b <- pred.density(BMSs10bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s10b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s10b, realized.y=BMSdataBoys[,1])

BMSs10cBoys <- bms(BMSdataBoys, g="RIC",mprior="fixed", mprior.size = 3)
options(scipen=999)
pdensStatic_s10c <- pred.density(BMSs10cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s10c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s10c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs11Boys <- bms(BMSdataBoys, g="RIC",mprior="random")
options(scipen=999)
pdensStatic_s11 <- pred.density(BMSs11Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s11$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s11, realized.y=BMSdataBoys[,1])




###### ================================================ ######
###### ============ g = BRIC = max(N, K^2) ============ ######
###### ================================================ ######

###### 1) uniform
BMSs5Boys <- bms(BMSdataBoys, g="BRIC",mprior="uniform")
options(scipen=999)
pdensStatic_s5 <- pred.density(BMSs5Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s5$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s5, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs6aBoys <- bms(BMSdataBoys, g="BRIC",mprior="fixed")
options(scipen=999)
pdensStatic_s6a <- pred.density(BMSs6aBoys,newdata=BMSdataBoys[,-1])
lps.bma(pdensStatic_s6a, realized.y=BMSdataBoys[,1])
KLD(pdensStatic_s6a$fit,BMSdataBoys[,1])

BMSs6bBoys <- bms(BMSdataBoys, g="BRIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s6b <- pred.density(BMSs6bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s6b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s6b, realized.y=BMSdataBoys[,1])

BMSs6cBoys <- bms(BMSdataBoys, g="BRIC",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s6c <- pred.density(BMSs6cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s6c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s6c, realized.y=BMSdataBoys[,1])




###### 3) random for beta-binomial
BMSs7Boys <- bms(BMSdataBoys, g="BRIC",mprior="random")
options(scipen=999)
pdensStatic_s7 <- pred.density(BMSs7Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s7$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s7, realized.y=BMSdataBoys[,1])




###### =========================================== ######
###### ============ g = HQ = log(N^3) ============ ######
###### =========================================== ######

###### 1) uniform
BMSs13Boys <- bms(BMSdataBoys, g="HQ",mprior="uniform")
options(scipen=999)
pdensStatic_s13 <- pred.density(BMSs13Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s13$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s13, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs14aBoys <- bms(BMSdataBoys, g="HQ",mprior="fixed")
options(scipen=999)
pdensStatic_s14a <- pred.density(BMSs14aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s14a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s14a, realized.y=BMSdataBoys[,1])

BMSs14bBoys <- bms(BMSdataBoys, g="HQ",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s14b <- pred.density(BMSs14bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s14b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s14b, realized.y=BMSdataBoys[,1])

BMSs14cBoys <- bms(BMSdataBoys, g="HQ",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s14c <- pred.density(BMSs14cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s14c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s14c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs15Boys <- bms(BMSdataBoys, g="HQ",mprior="random")
options(scipen=999)
pdensStatic_s15 <- pred.density(BMSs15Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s15$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s15, realized.y=BMSdataBoys[,1])




###### =============================================== ######
###### ============ g = EBL = max (F - 1) ============ ######
###### =============================================== ######

###### 1) uniform
BMSs17Boys <- bms(BMSdataBoys, g="EBL",mprior="uniform")
options(scipen=999)
pdensStatic_s17 <- pred.density(BMSs17Boys[1:45],newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s17$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s17, realized.y=BMSdataBoys[,1])

###### 2) fixed for binomial
BMSs18aBoys <- bms(BMSdataBoys, g="EBL",mprior="fixed")
options(scipen=999)
pdensStatic_s18a <- pred.density(BMSs18aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s18a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s18a, realized.y=BMSdataBoys[,1])


BMSs18bBoys <- bms(BMSdataBoys, g="EBL",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s18b <- pred.density(BMSs18bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s18b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s18b, realized.y=BMSdataBoys[,1])


BMSs18cBoys <- bms(BMSdataBoys, g="EBL",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s18c <- pred.density(BMSs18cBoys[1:30],newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s18c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s18c, realized.y=BMSdataBoys[,1])


###### 3) random for beta-binomial
BMSs19Boys <- bms(BMSdataBoys, g="EBL",mprior="random")
options(scipen=999)
pdensStatic_s19 <- pred.density(BMSs19Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s19$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s19, realized.y=BMSdataBoys[,1])






###### ======================================= ######
###### ============ g = hyper = 3 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs21Boys <- bms(BMSdataBoys, g="hyper = 3",mprior="uniform")
options(scipen=999)
pdensStatic_s21 <- pred.density(BMSs21Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s21$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s21, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs22aBoys <- bms(BMSdataBoys, g="hyper = 3",mprior="fixed")
options(scipen=999)
pdensStatic_s22a <- pred.density(BMSs22aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s22a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s22a, realized.y=BMSdataBoys[,1])

BMSs22bBoys <- bms(BMSdataBoys, g="hyper = 3",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s22b <- pred.density(BMSs22bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s22b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s22b, realized.y=BMSdataBoys[,1])

BMSs22cBoys <- bms(BMSdataBoys, g="hyper = 3",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s22c <- pred.density(BMSs22cBoys[1:60],newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s22c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s22c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs23Boys <- bms(BMSdataBoys, g="hyper = 3",mprior="random")
options(scipen=999)
pdensStatic_s23 <- pred.density(BMSs23Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s23$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s23, realized.y=BMSdataBoys[,1])






###### ======================================= ######
###### ============ g = hyper = 4 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs25Boys <- bms(BMSdataBoys, g="hyper = 4",mprior="uniform")
options(scipen=999)
pdensStatic_s25 <- pred.density(BMSs25Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s25$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s25, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs26aBoys <- bms(BMSdataBoys, g="hyper = 4",mprior="fixed")
options(scipen=999)
pdensStatic_s26a <- pred.density(BMSs26aBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s26a$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s26a, realized.y=BMSdataBoys[,1])

BMSs26bBoys <- bms(BMSdataBoys, g="hyper = 4",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s26b <- pred.density(BMSs26bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s26b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s26b, realized.y=BMSdataBoys[,1])

BMSs26cBoys <- bms(BMSdataBoys, g="hyper = 4",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s26c <- pred.density(BMSs26cBoys[1:60],newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s26c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s26c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs27Boys <- bms(BMSdataBoys, g="hyper = 4",mprior="random")
options(scipen=999)
pdensStatic_s27 <- pred.density(BMSs27Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s27$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s27, realized.y=BMSdataBoys[,1])






###### ========================================= ######
###### ============ g = hyper = UIP ============ ######
###### ========================================= ######

###### 1) uniform
BMSs29Boys <- bms(BMSdataBoys, g="hyper = UIP",mprior="uniform")
options(scipen=999)
pdensStatic_s29 <- pred.density(BMSs29Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s29$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s29, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs30aBoys <- bms(BMSdataBoys, g="hyper = UIP",mprior="fixed")
options(scipen=999)
pdensStatic_s30a <- pred.density(BMSs30aBoys,newdata=BMSdataBoys[,-1])
lps.bma(pdensStatic_s30a, realized.y=BMSdataBoys[,1])
KLD(pdensStatic_s30a$fit,BMSdataBoys[,1])

BMSs30bBoys <- bms(BMSdataBoys, g="hyper = UIP",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s30b <- pred.density(BMSs30bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s30b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s30b, realized.y=BMSdataBoys[,1])

BMSs30cBoys <- bms(BMSdataBoys, g="hyper = UIP",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s30c <- pred.density(BMSs30cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s30c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s30c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs31Boys <- bms(BMSdataBoys, g="hyper = UIP",mprior="random")
options(scipen=999)
pdensStatic_s31 <- pred.density(BMSs31Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s31$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s31, realized.y=BMSdataBoys[,1])






###### ========================================== ######
###### ============ g = hyper = RIC ============ ######
###### ========================================== ######


###### 1) uniform
BMSs36Boys <- bms(BMSdataBoys, g="hyper = 65/32",mprior="uniform")
options(scipen=999)
pdensStatic_s36 <- pred.density(BMSs36Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s36$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s36, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs37aBoys <- bms(BMSdataBoys, g="hyper = 65/32",mprior="fixed")
options(scipen=999)
pdensStatic_s37a <- pred.density(BMSs37aBoys,newdata=BMSdataBoys[,-1])
lps.bma(pdensStatic_s37a, realized.y=BMSdataBoys[,1])
KLD(pdensStatic_s37a$fit,BMSdataBoys[,1])

BMSs37bBoys <- bms(BMSdataBoys, g="hyper = 65/32",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s37b <- pred.density(BMSs37bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s37b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s37b, realized.y=BMSdataBoys[,1])


BMSs37cBoys <- bms(BMSdataBoys, g="hyper = 65/32",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s37c <- pred.density(BMSs37cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s37c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s37c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs38Boys <- bms(BMSdataBoys, g="hyper = 65/32",mprior="random")
options(scipen=999)
pdensStatic_s38 <- pred.density(BMSs38Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s38$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s38, realized.y=BMSdataBoys[,1])

###### ========================================== ######
###### ============ g = hyper = BRIC ============ ######
###### ========================================== ######

###### 1) uniform
BMSs33Boys <- bms(BMSdataBoys, g="hyper = BRIC",mprior="uniform")
options(scipen=999)
pdensStatic_s33 <- pred.density(BMSs33Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s33$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s33, realized.y=BMSdataBoys[,1])


###### 2) fixed for binomial
BMSs34aBoys <- bms(BMSdataBoys, g="hyper = BRIC",mprior="fixed")
options(scipen=999)
pdensStatic_s34a <- pred.density(BMSs34aBoys,newdata=BMSdataBoys[,-1])
lps.bma(pdensStatic_s34a, realized.y=BMSdataBoys[,1])
KLD(pdensStatic_s34a$fit,BMSdataBoys[,1])

BMSs34bBoys <- bms(BMSdataBoys, g="hyper = BRIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s34b <- pred.density(BMSs34bBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s34b$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s34b, realized.y=BMSdataBoys[,1])


BMSs34cBoys <- bms(BMSdataBoys, g="hyper = BRIC",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s34c <- pred.density(BMSs34cBoys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s34c$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s34c, realized.y=BMSdataBoys[,1])

###### 3) random for beta-binomial
BMSs35Boys <- bms(BMSdataBoys, g="hyper = BRIC",mprior="random")
options(scipen=999)
pdensStatic_s35 <- pred.density(BMSs35Boys,newdata=BMSdataBoys[,-1])
KLD(pdensStatic_s35$fit,BMSdataBoys[,1])
lps.bma(pdensStatic_s35, realized.y=BMSdataBoys[,1])






