## Intercept at first time point

##Nonlinear growth model NAEP Girls Math

# Install "lavaan" normally, install "blavaan" from source  -------

# install.packages("mice")
# install.packages("bayesplot")
# install.packages("lattice")
# install.packages("ggplot2")
# install.packages("car")
# install.packages("rstan")
# install.packages("rstantools")
# install.packages("lavaan")
# install.packages("blavaan")
# install.packages("runjags")
# install.packages("BMA")
# install.packages("psych")
# install.packages("DescTools")
# install.packages("LaplacesDemon")
# install.packages("BMS")
# install.packages("FNN")
# install.packages("forecast")
# install.packages("xtable")

library(mice)
library(lattice)
library(bayesplot)
library(ggplot2)
library(car)
library(lavaan)
library(blavaan)
library(BMA)
library(psych)
library(DescTools)
library(FNN)
library(forecast)
library(LaplacesDemon)
library(BMS)
library(xtable)
library(rstan)
library(rstantools)


# Data input and manipulation

# Read Final_Gender.csv   -------------

NAEPGenderScores <- read.csv("Final_Gender.csv", header=T) 
#  Remove Tennessee due to lack of data
NAEPGenderScores <- NAEPGenderScores[-c(43),]
NAEPGirlsMath <- subset(NAEPGenderScores,select=c(Jurisdiction,MathGirl03,MathGirl05,MathGirl07,MathGirl09,
                                         MathGirl11,MathGirl13,MathGirl15,MathGirl17,
                                         ReadingGirl03,ReadingGirl17))


# Read in Final_NAEP.csv
NAEPdataDemos  <- read.csv("Final_NAEP.csv", header=T)
#  Remove Tennessee due to lack of data
NAEPdataDemos <- NAEPdataDemos[-c(43),]


# Read in ccd.imputed.csv
CCDdata <- read.csv("CCD_imputed.csv", header=T)
#  Remove Tennessee due to lack of data
CCDdata <- CCDdata[-c(43),]


# Combine data
NAEPGirlsdata <- cbind(NAEPGirlsMath, NAEPdataDemos, CCDdata)


#################################################################
# Run Gen Diff NonLinear growth curve model:  THIS ONE SEEMS BEST ------
#################################################################

BayesNonLinGCM <- '
# intercept and slope with fixed coefficients
int =~ 1*MathGirl03+1*MathGirl05+1*MathGirl07+1*MathGirl09+1*MathGirl11+1*MathGirl13+1*MathGirl15+1*MathGirl17
slp =~ 0*MathGirl03+2*MathGirl05+4*MathGirl07+MathGirl09+MathGirl11+MathGirl13+MathGirl15+MathGirl17
int ~ prior("dnorm(260,.1)")*1
'
attach(NAEPGirlsdata)
#  Fit quadratic growth curve model and obtain predicted values ------
fitMathGirls <- bgrowth(BayesNonLinGCM, data=NAEPGirlsdata,save.lvs=TRUE,n.chains=2,
                      target="jags",adapt=5000,burnin=10000, sample=200000,test="none",
                      bcontrol=list(method="rjparallel"))
testMathGirlsSummary <- summary(fitMathGirls)

# Obtain predicted growth parameters and combine ------
lvmeansMathGirls <- blavInspect(fitMathGirls, "lvmeans")
newMathGirls <- cbind(NAEPGirlsdata,lvmeansMathGirls)
which(names(newMathGirls)%in%c("TOTEXP03"))
names(newMathGirls)[298:299]=c("int","slp")
time1 <- as.matrix(c(0, 2, 4, 6.46, 8.47, 9.60, 7.68, 7.42),nrow=1,ncol=8)   # Spline 


BaselineMathGirls <- newMathGirls[,298]  + newMathGirls[,299] %*% t(time1)
newMathGirls2 <- cbind(newMathGirls,BaselineMathGirls)
which(names(newMathGirls2)%in%c("slp"))
names(newMathGirls2)[300:307] =
  c("PredMathGirl03","PredMathGirl05","PredMathGirl07","PredMathGirl09",
    "PredMathGirl11","PredMathGirl13","PredMathGirl15","PredMathGirl17")


# Create difference scores for demographics
attach(newMathGirls2)
GirlsEnrollDiff = GENDER_FEMALE_17_g08m - GENDER_FEMALE_03_g08m
PTRatioDiff = PT_ratio17 - PT_ratio03
FTEdiff2 = (FTE17 - FTE03)/10000
TOTREVdiff = (TOTREV15 - TOTREV03)/10000
TOTEXPdiff <- (TOTEXP15 - TOTEXP03)/10000


AAdiff = SDRACEM_AM_IND_17_g08m - SDRACEM_AM_IND_03_g08m
ASdiff = SDRACEM_ASIAN_PI_17_g08m - SDRACEM_ASIAN_PI_03_g08m
HIdiff = SDRACEM_HISPAN_17_g08m - SDRACEM_HISPAN_03_g08m
BLdiff = SDRACEM_BLACK_17_g08m - SDRACEM_BLACK_03_g08m
WHdiff = SDRACEM_WHITE_17_g08m - SDRACEM_WHITE_03_g08m


ReadGirlDiff = ReadingGirl17 - ReadingGirl03

NSLPLunchDiff = SLUNCH1_ELIGIBLE_17_g08m - SLUNCH1_ELIGIBLE_03_g08m

attach(newMathGirls2)
NAEPGirlsdata2 <- cbind(newMathGirls2,GirlsEnrollDiff, PTRatioDiff,
                       FTEdiff2,
                       NSLPLunchDiff ,
                       TOTREVdiff,
                       ReadGirlDiff)

## BMA prediction of slope  ------

which(names(NAEPGirlsdata2)%in%c("slp","GirlsEnrollDiff", "PTRatioDiff",
                                 "FTEdiff2",
                                 "NSLPLunchDiff",
                                 "TOTREVdiff",
                                 "ReadGirlDiff"
                              ))
BMSdataGirls <- NAEPGirlsdata2[,c(299, 308, 309, 310, 311, 312, 313)]

###  Conduct BMA and assess sensitivity to differnt parameter and model prior settings ###


###### =============================================== ######
###### ================ g = uip = 1/N ================ ######
###### =============================================== ######

# LPS for static forecast - slope  g=uip, mprior=uniform
###### 1) uniform
BMSs1Girls <- bms(BMSdataGirls, g="uip",mprior="uniform")
options(scipen=999)
pdensStatic_s1 <- pred.density(BMSs1Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s1$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s1, realized.y=BMSdataGirls[,1])

# plotModelsize(BMSs1Girls)

###### 2) fixed for binomial
BMSs2aGirls <- bms(BMSdataGirls, g="uip", mprior="fixed")
options(scipen=999)
pdensStatic_s2a <- pred.density(BMSs2aGirls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s2a, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s2a$fit,BMSdataGirls[,1])

BMSs2bGirls <- bms(BMSdataGirls, g="uip", mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s2b <- pred.density(BMSs2bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s2b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s2b, realized.y=BMSdataGirls[,1])


BMSs2cGirls <- bms(BMSdataGirls, g="uip", mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s2c <- pred.density(BMSs2cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s2c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s2c, realized.y=BMSdataGirls[,1])



###### 3) random for beta-binomial
BMSs3Girls <- bms(BMSdataGirls, g="uip",mprior="random")
options(scipen=999)
pdensStatic_s3 <- pred.density(BMSs3Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s3$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s3, realized.y=BMSdataGirls[,1])



###### 4) pip for prior inclusion probabilities
BMSs4Girls <- bms(BMSdataGirls, g="uip",mprior="pip")
options(scipen=999)
pdensStatic_s4 <- pred.density(BMSs4Girls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s4, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s4$fit,BMSdataGirls[,1])

###### ======================================= ######
###### ============ g = RIC = K^2 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs9Girls <- bms(BMSdataGirls, g="RIC",mprior="uniform")
options(scipen=999)
pdensStatic_s9 <- pred.density(BMSs9Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s9$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s9, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs10aGirls <- bms(BMSdataGirls, g="RIC",mprior="fixed")
options(scipen=999)
pdensStatic_s10a <- pred.density(BMSs10aGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s10a$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s10a, realized.y=BMSdataGirls[,1])

BMSs10bGirls <- bms(BMSdataGirls, g="RIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s10b <- pred.density(BMSs10bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s10b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s10b, realized.y=BMSdataGirls[,1])

BMSs10cGirls <- bms(BMSdataGirls, g="RIC",mprior="fixed", mprior.size = 3)
options(scipen=999)
pdensStatic_s10c <- pred.density(BMSs10cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s10c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s10c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs11Girls <- bms(BMSdataGirls, g="RIC",mprior="random")
options(scipen=999)
pdensStatic_s11 <- pred.density(BMSs11Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s11$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s11, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs12Girls <- bms(BMSdataGirls, g="RIC",mprior="pip")
options(scipen=999)
pdensStatic_s12 <- pred.density(BMSs12Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s12$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s12, realized.y=BMSdataGirls[,1])


###### ================================================ ######
###### ============ g = BRIC = max(N, K^2) ============ ######
###### ================================================ ######

###### 1) uniform
BMSs5Girls <- bms(BMSdataGirls, g="BRIC",mprior="uniform")
options(scipen=999)
pdensStatic_s5 <- pred.density(BMSs5Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s5$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s5, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs6aGirls <- bms(BMSdataGirls, g="BRIC",mprior="fixed")
options(scipen=999)
pdensStatic_s6a <- pred.density(BMSs6aGirls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s6a, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s6a$fit,BMSdataGirls[,1])

BMSs6bGirls <- bms(BMSdataGirls, g="BRIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s6b <- pred.density(BMSs6bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s6b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s6b, realized.y=BMSdataGirls[,1])

BMSs6cGirls <- bms(BMSdataGirls, g="BRIC",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s6c <- pred.density(BMSs6cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s6c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s6c, realized.y=BMSdataGirls[,1])



###### 3) random for beta-binomial
BMSs7Girls <- bms(BMSdataGirls, g="BRIC",mprior="random")
options(scipen=999)
pdensStatic_s7 <- pred.density(BMSs7Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s7$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s7, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs8Girls <- bms(BMSdataGirls, g="BRIC",mprior="pip")
options(scipen=999)
pdensStatic_s8 <- pred.density(BMSs8Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s8$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s8, realized.y=BMSdataGirls[,1])


###### =========================================== ######
###### ============ g = HQ = log(N^3) ============ ######
###### =========================================== ######

###### 1) uniform
BMSs13Girls <- bms(BMSdataGirls, g="HQ",mprior="uniform")
options(scipen=999)
pdensStatic_s13 <- pred.density(BMSs13Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s13$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s13, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs14aGirls <- bms(BMSdataGirls, g="HQ",mprior="fixed")
options(scipen=999)
pdensStatic_s14a <- pred.density(BMSs14aGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s14a$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s14a, realized.y=BMSdataGirls[,1])

BMSs14bGirls <- bms(BMSdataGirls, g="HQ",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s14b <- pred.density(BMSs14bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s14b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s14b, realized.y=BMSdataGirls[,1])

BMSs14cGirls <- bms(BMSdataGirls, g="HQ",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s14c <- pred.density(BMSs14cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s14c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s14c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs15Girls <- bms(BMSdataGirls, g="HQ",mprior="random")
options(scipen=999)
pdensStatic_s15 <- pred.density(BMSs15Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s15$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s15, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs16Girls <- bms(BMSdataGirls, g="HQ",mprior="pip")
options(scipen=999)
pdensStatic_s16 <- pred.density(BMSs16Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s16$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s16, realized.y=BMSdataGirls[,1])


###### =============================================== ######
###### ============ g = EBL = max (F - 1) ============ ######
###### =============================================== ######

###### 1) uniform
BMSs17Girls <- bms(BMSdataGirls, g="EBL",mprior="uniform")
options(scipen=999)
pdensStatic_s17 <- pred.density(BMSs17Girls[1:60],newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s17$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s17, realized.y=BMSdataGirls[,1])

###### 2) fixed for binomial
BMSs18aGirls <- bms(BMSdataGirls, g="EBL",mprior="fixed")
options(scipen=999)
pdensStatic_s18a <- pred.density(BMSs18aGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s18a$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s18a, realized.y=BMSdataGirls[,1])


BMSs18bGirls <- bms(BMSdataGirls, g="EBL",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s18b <- pred.density(BMSs18bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s18b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s18b, realized.y=BMSdataGirls[,1])


BMSs18cGirls <- bms(BMSdataGirls, g="EBL",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s18c <- pred.density(BMSs18cGirls[1:55],newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s18c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s18c, realized.y=BMSdataGirls[,1])


###### 3) random for beta-binomial
BMSs19Girls <- bms(BMSdataGirls, g="EBL",mprior="random")
options(scipen=999)
pdensStatic_s19 <- pred.density(BMSs19Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s19$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s19, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs20Girls <- bms(BMSdataGirls, g="EBL",mprior="pip")
options(scipen=999)
pdensStatic_s20 <- pred.density(BMSs20Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s20$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s20, realized.y=BMSdataGirls[,1])



###### ======================================= ######
###### ============ g = hyper = 3 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs21Girls <- bms(BMSdataGirls, g="hyper = 3",mprior="uniform")
options(scipen=999)
pdensStatic_s21 <- pred.density(BMSs21Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s21$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s21, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs22aGirls <- bms(BMSdataGirls, g="hyper = 3",mprior="fixed")
options(scipen=999)
pdensStatic_s22a <- pred.density(BMSs22aGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s22a$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s22a, realized.y=BMSdataGirls[,1])

BMSs22bGirls <- bms(BMSdataGirls, g="hyper = 3",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s22b <- pred.density(BMSs22bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s22b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s22b, realized.y=BMSdataGirls[,1])

BMSs22cGirls <- bms(BMSdataGirls, g="hyper = 3",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s22c <- pred.density(BMSs22cGirls[1:60],newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s22c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s22c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs23Girls <- bms(BMSdataGirls, g="hyper = 3",mprior="random")
options(scipen=999)
pdensStatic_s23 <- pred.density(BMSs23Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s23$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s23, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs24Girls <- bms(BMSdataGirls, g="hyper = 3",mprior="pip")
options(scipen=999)
pdensStatic_s24 <- pred.density(BMSs24Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s24$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s24, realized.y=BMSdataGirls[,1])



###### ======================================= ######
###### ============ g = hyper = 4 ============ ######
###### ======================================= ######

###### 1) uniform
BMSs25Girls <- bms(BMSdataGirls, g="hyper = 4",mprior="uniform")
options(scipen=999)
pdensStatic_s25 <- pred.density(BMSs25Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s25$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s25, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs26aGirls <- bms(BMSdataGirls, g="hyper = 4",mprior="fixed")
options(scipen=999)
pdensStatic_s26a <- pred.density(BMSs26aGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s26a$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s26a, realized.y=BMSdataGirls[,1])

BMSs26bGirls <- bms(BMSdataGirls, g="hyper = 4",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s26b <- pred.density(BMSs26bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s26b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s26b, realized.y=BMSdataGirls[,1])

BMSs26cGirls <- bms(BMSdataGirls, g="hyper = 4",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s26c <- pred.density(BMSs26cGirls[1:60],newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s26c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s26c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs27Girls <- bms(BMSdataGirls, g="hyper = 4",mprior="random")
options(scipen=999)
pdensStatic_s27 <- pred.density(BMSs27Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s27$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s27, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs28Girls <- bms(BMSdataGirls, g="hyper = 4",mprior="pip")
options(scipen=999)
pdensStatic_s28 <- pred.density(BMSs28Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s28$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s28, realized.y=BMSdataGirls[,1])




###### ========================================= ######
###### ============ g = hyper = UIP ============ ######
###### ========================================= ######

###### 1) uniform
BMSs29Girls <- bms(BMSdataGirls, g="hyper = UIP",mprior="uniform")
options(scipen=999)
pdensStatic_s29 <- pred.density(BMSs29Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s29$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s29, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs30aGirls <- bms(BMSdataGirls, g="hyper = UIP",mprior="fixed")
options(scipen=999)
pdensStatic_s30a <- pred.density(BMSs30aGirls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s30a, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s30a$fit,BMSdataGirls[,1])

BMSs30bGirls <- bms(BMSdataGirls, g="hyper = UIP",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s30b <- pred.density(BMSs30bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s30b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s30b, realized.y=BMSdataGirls[,1])

BMSs30cGirls <- bms(BMSdataGirls, g="hyper = UIP",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s30c <- pred.density(BMSs30cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s30c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s30c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs31Girls <- bms(BMSdataGirls, g="hyper = UIP",mprior="random")
options(scipen=999)
pdensStatic_s31 <- pred.density(BMSs31Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s31$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s31, realized.y=BMSdataGirls[,1])


###### 4) pip for prior inclusion probabilities
BMSs32Girls <- bms(BMSdataGirls, g="hyper = UIP",mprior="pip")
options(scipen=999)
pdensStatic_s32 <- pred.density(BMSs32Girls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s32, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s32$fit,BMSdataGirls[,1])




###### ========================================== ######
###### ============ g = hyper = RIC ============ ######
###### ========================================== ######


###### 1) uniform
BMSs36Girls <- bms(BMSdataGirls, g="hyper = 65/32",mprior="uniform")
options(scipen=999)
pdensStatic_s36 <- pred.density(BMSs36Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s36$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s36, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs37aGirls <- bms(BMSdataGirls, g="hyper = 65/32",mprior="fixed")
options(scipen=999)
pdensStatic_s37a <- pred.density(BMSs37aGirls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s37a, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s37a$fit,BMSdataGirls[,1])

BMSs37bGirls <- bms(BMSdataGirls, g="hyper = 65/32",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s37b <- pred.density(BMSs37bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s37b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s37b, realized.y=BMSdataGirls[,1])


BMSs37cGirls <- bms(BMSdataGirls, g="hyper = 65/32",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s37c <- pred.density(BMSs37cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s37c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s37c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs38Girls <- bms(BMSdataGirls, g="hyper = 65/32",mprior="random")
options(scipen=999)
pdensStatic_s38 <- pred.density(BMSs38Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s38$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s38, realized.y=BMSdataGirls[,1])

###### ========================================== ######
###### ============ g = hyper = BRIC ============ ######
###### ========================================== ######

###### 1) uniform
BMSs33Girls <- bms(BMSdataGirls, g="hyper = BRIC",mprior="uniform")
options(scipen=999)
pdensStatic_s33 <- pred.density(BMSs33Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s33$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s33, realized.y=BMSdataGirls[,1])


###### 2) fixed for binomial
BMSs34aGirls <- bms(BMSdataGirls, g="hyper = BRIC",mprior="fixed")
options(scipen=999)
pdensStatic_s34a <- pred.density(BMSs34aGirls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s34a, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s34a$fit,BMSdataGirls[,1])

BMSs34bGirls <- bms(BMSdataGirls, g="hyper = BRIC",mprior="fixed", mprior.size = 2)
options(scipen=999)
pdensStatic_s34b <- pred.density(BMSs34bGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s34b$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s34b, realized.y=BMSdataGirls[,1])


BMSs34cGirls <- bms(BMSdataGirls, g="hyper = BRIC",mprior="fixed", mprior.size = 4)
options(scipen=999)
pdensStatic_s34c <- pred.density(BMSs34cGirls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s34c$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s34c, realized.y=BMSdataGirls[,1])

###### 3) random for beta-binomial
BMSs35Girls <- bms(BMSdataGirls, g="hyper = BRIC",mprior="random")
options(scipen=999)
pdensStatic_s35 <- pred.density(BMSs35Girls,newdata=BMSdataGirls[,-1])
KLD(pdensStatic_s35$fit,BMSdataGirls[,1])
lps.bma(pdensStatic_s35, realized.y=BMSdataGirls[,1])



###### 4) pip for prior inclusion probabilities
BMSs36Girls <- bms(BMSdataGirls, g="hyper = BRIC")
options(scipen=999)
pdensStatic_s36 <- pred.density(BMSs36Girls,newdata=BMSdataGirls[,-1])
lps.bma(pdensStatic_s36, realized.y=BMSdataGirls[,1])
KLD(pdensStatic_s36$fit,BMSdataGirls[,1])

